#
# Copyright (c) 2016-2020 MasterCard International Incorporated
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are
# permitted provided that the following conditions are met:
#
# Redistributions of source code must retain the above copyright notice, this list of
# conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice, this list of
# conditions and the following disclaimer in the documentation and/or other materials
# provided with the distribution.
# Neither the name of the MasterCard International Incorporated nor the names of its
# contributors may be used to endorse or promote products derived from this software
# without specific prior written permission.
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
# SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
# IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
# IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#


require "mastercard/core/model"
require "mastercard/core/baseobject"

module MasterCard
    module API
        module Qkr
            class Beneficiary < MasterCard::Core::Model::BaseObject
                include MasterCard::Core::Model
                #

                @__store = {
                    'ceef4eca-f757-4b0d-a9b9-4681f48007be' => OperationConfig.new("/labs/proxy/qkr2/internal/api2/beneficiary", "create", ["X-Auth-Token"], []),
                    '48200200-18f0-4393-b32e-1837cd1ba78c' => OperationConfig.new("/labs/proxy/qkr2/internal/api2/beneficiary/{id}", "delete", ["X-Auth-Token"], []),
                    '45f93f11-e3be-474e-a097-642aeae0e184' => OperationConfig.new("/labs/proxy/qkr2/internal/api2/beneficiary", "query", ["X-Auth-Token"], ["merchantId"]),
                    '73c94ecd-720f-448d-8a1f-82ce5083b34a' => OperationConfig.new("/labs/proxy/qkr2/internal/api2/beneficiary/{id}", "update", ["X-Auth-Token"], []),
                    
                }

                protected

                def self.getOperationConfig(operationUUID)
                    if @__store.key?(operationUUID)
                        return @__store[operationUUID]
                    end
                    raise NotImplementedError.new("Invalid operationUUID supplied:"+ operationUUID)
                end

                def self.getOperationMetadata()
                    return OperationMetadata.new(ResourceConfig.instance.getVersion(), ResourceConfig.instance.getHost(), ResourceConfig.instance.getContext(), ResourceConfig.instance.getJsonNative(), ResourceConfig.instance.getContentTypeOverride())
                end

                public


                def self.create(mapObj)
                    #
                    #Creates object of type Beneficiary
                    #
                    #@param Dict mapObj, containing the required parameters to create a new object
                    #@return [Beneficiary] of the response of created instance.
                    #@raise [APIException] an exception from the response status
                    return self.execute("ceef4eca-f757-4b0d-a9b9-4681f48007be", Beneficiary.new(mapObj))
                end










                def self.deleteById(id, map = nil)
                    #Delete object of type Beneficiary by id

                    #@param [String] id
                    #@param [Dict] map, containing additional parameters
                    #@return [Beneficiary] of the response of the deleted instance.
                    #@raise [APIException] an exception from the response status


                    mapObj = Beneficiary.new
                    if !(id.nil? || id.to_s.empty?)
                      mapObj.set("id", id)
                    end
                    if !map.nil?
                        if map.instance_of? RequestMap
                          mapObj.setAll(map.getObject())
                        else
                          mapObj.setAll(map)
                        end
                    end

                    return self.execute("48200200-18f0-4393-b32e-1837cd1ba78c", mapObj)
                end


                def delete
                    #
                    #Delete object of type Beneficiary

                    #@param [String] id
                    #@return [Beneficiary] of the response of the deleted instance.
                    #@raise [APIException] an exception from the response status
                    #

                    return self.class.execute("48200200-18f0-4393-b32e-1837cd1ba78c", self)
                end









                def self.query(criteria)
                    #
                    #Query objects of type Beneficiary by id and optional criteria
                    #@param [Dict] criteria
                    #@return [Beneficiary] object representing the response.
                    #@raise [APIException] an exception from the response status
                    #

                    return self.execute("45f93f11-e3be-474e-a097-642aeae0e184",Beneficiary.new(criteria))
                end



                def update
                    #
                    #Updates an object of type Beneficiary
                    #
                    #@return [Beneficiary] object representing the response.
                    #@raise [APIException] an exception from the response status
                    #
                    return self.class.execute("73c94ecd-720f-448d-8a1f-82ce5083b34a",self)
                end







            end
        end
    end
end







