#
# Copyright (c) 2016-2020 MasterCard International Incorporated
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are
# permitted provided that the following conditions are met:
#
# Redistributions of source code must retain the above copyright notice, this list of
# conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice, this list of
# conditions and the following disclaimer in the documentation and/or other materials
# provided with the distribution.
# Neither the name of the MasterCard International Incorporated nor the names of its
# contributors may be used to endorse or promote products derived from this software
# without specific prior written permission.
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
# SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
# IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
# IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#


require "mastercard/core/model"
require "mastercard/core/baseobject"

module MasterCard
    module API
        module Qkr
            class Order < MasterCard::Core::Model::BaseObject
                include MasterCard::Core::Model
                #

                @__store = {
                    'e0a0b4a1-1805-4a52-a731-8bf7ab448fc9' => OperationConfig.new("/labs/proxy/qkr2/internal/api2/order/pat", "create", [], []),
                    'e4d30151-a10f-43d8-b803-42ef41881237' => OperationConfig.new("/labs/proxy/qkr2/internal/api2/order/pat/{id}", "delete", [], []),
                    '6062912f-d4d3-4c28-9c50-f7ec56b29df6' => OperationConfig.new("/labs/proxy/qkr2/internal/api2/order/pat/{id}", "read", [], []),
                    'ca1fe4a4-7139-4f00-bf3d-a78e68facd32' => OperationConfig.new("/labs/proxy/qkr2/internal/api2/order/pat/{id}", "update", [], []),
                    
                }

                protected

                def self.getOperationConfig(operationUUID)
                    if @__store.key?(operationUUID)
                        return @__store[operationUUID]
                    end
                    raise NotImplementedError.new("Invalid operationUUID supplied:"+ operationUUID)
                end

                def self.getOperationMetadata()
                    return OperationMetadata.new(ResourceConfig.instance.getVersion(), ResourceConfig.instance.getHost(), ResourceConfig.instance.getContext(), ResourceConfig.instance.getJsonNative(), ResourceConfig.instance.getContentTypeOverride())
                end

                public


                def self.create(mapObj)
                    #
                    #Creates object of type Order
                    #
                    #@param Dict mapObj, containing the required parameters to create a new object
                    #@return [Order] of the response of created instance.
                    #@raise [APIException] an exception from the response status
                    return self.execute("e0a0b4a1-1805-4a52-a731-8bf7ab448fc9", Order.new(mapObj))
                end










                def self.deleteById(id, map = nil)
                    #Delete object of type Order by id

                    #@param [String] id
                    #@param [Dict] map, containing additional parameters
                    #@return [Order] of the response of the deleted instance.
                    #@raise [APIException] an exception from the response status


                    mapObj = Order.new
                    if !(id.nil? || id.to_s.empty?)
                      mapObj.set("id", id)
                    end
                    if !map.nil?
                        if map.instance_of? RequestMap
                          mapObj.setAll(map.getObject())
                        else
                          mapObj.setAll(map)
                        end
                    end

                    return self.execute("e4d30151-a10f-43d8-b803-42ef41881237", mapObj)
                end


                def delete
                    #
                    #Delete object of type Order

                    #@param [String] id
                    #@return [Order] of the response of the deleted instance.
                    #@raise [APIException] an exception from the response status
                    #

                    return self.class.execute("e4d30151-a10f-43d8-b803-42ef41881237", self)
                end








                def self.read(id, criteria = nil)
                    #
                    #Returns objects of type Order by id and optional criteria
                    #@param [String] id
                    #@param [Dict] criteria
                    #@return [Order] object representing the response
                    #@raise [APIException] an exception from the response status

                    mapObj = Order.new
                    if !(id.nil? || id.to_s.empty?)
                      mapObj.set("id", id)
                    end
                    if !criteria.nil?
                        if criteria.instance_of? RequestMap
                          mapObj.setAll(criteria.getObject())
                        else
                          mapObj.setAll(criteria)
                        end
                    end

                    return self.execute("6062912f-d4d3-4c28-9c50-f7ec56b29df6",Order.new(mapObj))
                end




                def update
                    #
                    #Updates an object of type Order
                    #
                    #@return [Order] object representing the response.
                    #@raise [APIException] an exception from the response status
                    #
                    return self.class.execute("ca1fe4a4-7139-4f00-bf3d-a78e68facd32",self)
                end







            end
        end
    end
end







